import request from '@/config/axios'
import * as DataPointApi from '@/api/data/da/point'
import * as PredictItemApi from '@/api/model/pre/item'
import {CommonEnabled} from "@/utils/constants";

export interface ScheduleModelVO {
  id: string
  modelCode: string
  modelName: string
  modelType: string
  className: string
  methodName: string
  portLength: number
  paramStructure: string
  modelPath: string
  resultStrId: string
  invocation: string
  status: number,
  paramList: null,
  settingList: null
}

export interface ModelParamVO {
  modelparamportorder: number
  modelparamorder: number
  modelparamtype: string
  modelparamid: string
  datalength: number
}

export interface WorkPrecessParamVO {
  processType: string
}

export interface ScheduleModelPageReqVO extends PageParam {
  modelCode?: string
  modelName?: string
}

// 查询ScheduleModel列表
export const getScheduleModelPage = (params: ScheduleModelPageReqVO) => {
  return request.get({ url: '/model/sche/model/page', params })
}

// 查询ScheduleModel详情
export const getScheduleModel = (id: number) => {
  return request.get({ url: '/model/sche/model/get?id=' + id})
}

// 新增ScheduleModel
export const createScheduleModel = (data: ScheduleModelVO) => {
  return request.post({ url: '/model/sche/model/create', data })
}

// 修改ScheduleModel
export const updateScheduleModel = (data: ScheduleModelVO) => {
  return request.put({ url: '/model/sche/model/update', data })
}

// 删除ScheduleModel
export const deleteScheduleModel = (id: number) => {
  return request.delete({ url: '/model/sche/model/delete?id=' + id })
}

// 查询ScheduleModel列表
export const getScheduleModelList = () => {
  return request.get({ url: '/model/sche/model/list'})
}

// 查询模型参数列表
export const getModelParamList = async () => {

  const dataPointList = ref([] as DataPointApi.DaPointVO)
  dataPointList.value = await DataPointApi.getPointList({})
  const pointList = []
  if (dataPointList.value) {
    dataPointList.value.forEach(item => {
      pointList.push(
        {
          id: item.id,
          name: item.pointName
        }
      )
    })
  }

  const predictItemList = ref([] as PredictItemApi.MmPredictItemVO)
  predictItemList.value = await PredictItemApi.getMmPredictItemList({
    status: CommonEnabled.ENABLE,
    itemtypename: 'NormalItem'
  })
  const itemList = []
  if (predictItemList.value) {
    predictItemList.value.forEach(item => {
      itemList.push(
        {
          id: item.id,
          name:  item.itemname
        }
      )
    })
  }
  return {
    'DATAPOINT':pointList,
    'PREDICTITEM': itemList
  }
}
